@@ -19,8 +19,6 @@
 
 import warnings
 
-from six import add_metaclass
-
 from logilab.common.testlib import TestCase, unittest_main
 from logilab.common import deprecation
 
@@ -47,8 +45,7 @@ class RawInputTC(TestCase):
         return any_func
 
     def test_class_deprecated(self):
-        @add_metaclass(deprecation.class_deprecated)
-        class AnyClass(object):
+        class AnyClass(object, metaclass=deprecation.class_deprecated):
             pass
         AnyClass()
         self.assertEqual(self.messages,
@@ -107,8 +104,7 @@ class RawInputTC(TestCase):
     def test_class_deprecated_manager(self):
         deprecator = deprecation.DeprecationManager("module_name")
         deprecator.compatibility('1.3')
-        @add_metaclass(deprecator.class_deprecated('1.2'))
-        class AnyClass(object):
+        class AnyClass(object, metaclass=deprecator.class_deprecated('1.2')):
             pass
         AnyClass()
         self.assertEqual(self.messages,
